@@ -100,16 +100,11 @@ def process_temporary_deprecated_settings(config: Dict[str, Any]) -> None:
             "from the edge configuration."
         )
     if 'ticker_interval' in config:
-        logger.warning(
-            "DEPRECATED: "
+
+        raise OperationalException(
+            "DEPRECATED: 'ticker_interval' detected. "
             "Please use 'timeframe' instead of 'ticker_interval."
         )
-        if 'timeframe' in config:
-            raise OperationalException(
-                "Both 'timeframe' and 'ticker_interval' detected."
-                "Please remove 'ticker_interval' from your configuration to continue operating."
-            )
-        config['timeframe'] = config['ticker_interval']
 
     if 'protections' in config:
         logger.warning("DEPRECATED: Setting 'protections' in the configuration is deprecated.")
