@@ -140,7 +140,7 @@ CONF_SCHEMA = {
             'minProperties': 1
         },
         'amount_reserve_percent': {'type': 'number', 'minimum': 0.0, 'maximum': 0.5},
-        'stoploss': {'type': 'number', 'maximum': 0, 'exclusiveMaximum': True},
+        'stoploss': {'type': 'number', 'maximum': 0, 'exclusiveMaximum': True, 'minimum': -1},
         'trailing_stop': {'type': 'boolean'},
         'trailing_stop_positive': {'type': 'number', 'minimum': 0, 'maximum': 1},
         'trailing_stop_positive_offset': {'type': 'number', 'minimum': 0, 'maximum': 1},
@@ -440,7 +440,6 @@ SCHEMA_TRADE_REQUIRED = [
     'dry_run_wallet',
     'ask_strategy',
     'bid_strategy',
-    'unfilledtimeout',
     'stoploss',
     'minimal_roi',
     'internals',
@@ -456,7 +455,6 @@ SCHEMA_BACKTEST_REQUIRED = [
     'dry_run_wallet',
     'dataformat_ohlcv',
     'dataformat_trades',
-    'unfilledtimeout',
 ]
 
 SCHEMA_MINIMAL_REQUIRED = [
