@@ -4,6 +4,7 @@ Spread pair list filter
 import logging
 from typing import Any, Dict
 
+from freqtrade.exceptions import OperationalException
 from freqtrade.plugins.pairlist.IPairList import IPairList
 
 
@@ -20,6 +21,12 @@ class SpreadFilter(IPairList):
         self._max_spread_ratio = pairlistconfig.get('max_spread_ratio', 0.005)
         self._enabled = self._max_spread_ratio != 0
 
+        if not self._exchange.exchange_has('fetchTickers'):
+            raise OperationalException(
+                'Exchange does not support fetchTickers, therefore SpreadFilter cannot be used.'
+                'Please edit your config and restart the bot.'
+            )
+
     @property
     def needstickers(self) -> bool:
         """
