@@ -107,6 +107,8 @@ def patch_exchange(mocker, api_mock=None, id='binance', mock_markets=True) -> No
         mocker.patch('freqtrade.exchange.Exchange._init_ccxt', MagicMock(return_value=api_mock))
     else:
         mocker.patch('freqtrade.exchange.Exchange._init_ccxt', MagicMock())
+        mocker.patch('freqtrade.exchange.Exchange.timeframes', PropertyMock(
+                return_value=['5m', '15m', '1h', '1d']))
 
 
 def get_patched_exchange(mocker, config, api_mock=None, id='binance',
@@ -1017,8 +1019,8 @@ def limit_buy_order_open():
         'type': 'limit',
         'side': 'buy',
         'symbol': 'mocked',
+        'timestamp': arrow.utcnow().int_timestamp * 1000,
         'datetime': arrow.utcnow().isoformat(),
-        'timestamp': arrow.utcnow().int_timestamp,
         'price': 0.00001099,
         'amount': 90.99181073,
         'filled': 0.0,
@@ -1044,6 +1046,7 @@ def market_buy_order():
         'type': 'market',
         'side': 'buy',
         'symbol': 'mocked',
+        'timestamp': arrow.utcnow().int_timestamp * 1000,
         'datetime': arrow.utcnow().isoformat(),
         'price': 0.00004099,
         'amount': 91.99181073,
@@ -1060,6 +1063,7 @@ def market_sell_order():
         'type': 'market',
         'side': 'sell',
         'symbol': 'mocked',
+        'timestamp': arrow.utcnow().int_timestamp * 1000,
         'datetime': arrow.utcnow().isoformat(),
         'price': 0.00004173,
         'amount': 91.99181073,
@@ -1076,7 +1080,8 @@ def limit_buy_order_old():
         'type': 'limit',
         'side': 'buy',
         'symbol': 'mocked',
-        'datetime': str(arrow.utcnow().shift(minutes=-601).datetime),
+        'datetime': arrow.utcnow().shift(minutes=-601).isoformat(),
+        'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp * 1000,
         'price': 0.00001099,
         'amount': 90.99181073,
         'filled': 0.0,
@@ -1092,6 +1097,7 @@ def limit_sell_order_old():
         'type': 'limit',
         'side': 'sell',
         'symbol': 'ETH/BTC',
+        'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp * 1000,
         'datetime': arrow.utcnow().shift(minutes=-601).isoformat(),
         'price': 0.00001099,
         'amount': 90.99181073,
@@ -1108,6 +1114,7 @@ def limit_buy_order_old_partial():
         'type': 'limit',
         'side': 'buy',
         'symbol': 'ETH/BTC',
+        'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp * 1000,
         'datetime': arrow.utcnow().shift(minutes=-601).isoformat(),
         'price': 0.00001099,
         'amount': 90.99181073,
@@ -1137,7 +1144,7 @@ def limit_buy_order_canceled_empty(request):
             'info': {},
             'id': '1234512345',
             'clientOrderId': None,
-            'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp,
+            'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp * 1000,
             'datetime': arrow.utcnow().shift(minutes=-601).isoformat(),
             'lastTradeTimestamp': None,
             'symbol': 'LTC/USDT',
@@ -1158,7 +1165,7 @@ def limit_buy_order_canceled_empty(request):
             'info': {},
             'id': 'AZNPFF-4AC4N-7MKTAT',
             'clientOrderId': None,
-            'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp,
+            'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp * 1000,
             'datetime': arrow.utcnow().shift(minutes=-601).isoformat(),
             'lastTradeTimestamp': None,
             'status': 'canceled',
@@ -1179,7 +1186,7 @@ def limit_buy_order_canceled_empty(request):
             'info': {},
             'id': '1234512345',
             'clientOrderId': 'alb1234123',
-            'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp,
+            'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp * 1000,
             'datetime': arrow.utcnow().shift(minutes=-601).isoformat(),
             'lastTradeTimestamp': None,
             'symbol': 'LTC/USDT',
@@ -1200,7 +1207,7 @@ def limit_buy_order_canceled_empty(request):
             'info': {},
             'id': '1234512345',
             'clientOrderId': 'alb1234123',
-            'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp,
+            'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp * 1000,
             'datetime': arrow.utcnow().shift(minutes=-601).isoformat(),
             'lastTradeTimestamp': None,
             'symbol': 'LTC/USDT',
@@ -1226,7 +1233,7 @@ def limit_sell_order_open():
         'side': 'sell',
         'symbol': 'mocked',
         'datetime': arrow.utcnow().isoformat(),
-        'timestamp': arrow.utcnow().int_timestamp,
+        'timestamp': arrow.utcnow().int_timestamp * 1000,
         'price': 0.00001173,
         'amount': 90.99181073,
         'filled': 0.0,
@@ -1392,7 +1399,7 @@ def tickers():
         'BLK/BTC': {
             'symbol': 'BLK/BTC',
             'timestamp': 1522014806072,
-            'datetime': '2018-03-25T21:53:26.720Z',
+            'datetime': '2018-03-25T21:53:26.072Z',
             'high': 0.007745,
             'low': 0.007512,
             'bid': 0.007729,
@@ -1888,7 +1895,8 @@ def buy_order_fee():
         'type': 'limit',
         'side': 'buy',
         'symbol': 'mocked',
-        'datetime': str(arrow.utcnow().shift(minutes=-601).datetime),
+        'timestamp': arrow.utcnow().shift(minutes=-601).int_timestamp * 1000,
+        'datetime': arrow.utcnow().shift(minutes=-601).isoformat(),
         'price': 0.245441,
         'amount': 8.0,
         'cost': 1.963528,
@@ -2186,7 +2194,7 @@ def limit_buy_order_usdt_open():
         'side': 'buy',
         'symbol': 'mocked',
         'datetime': arrow.utcnow().isoformat(),
-        'timestamp': arrow.utcnow().int_timestamp,
+        'timestamp': arrow.utcnow().int_timestamp * 1000,
         'price': 2.00,
         'amount': 30.0,
         'filled': 0.0,
@@ -2213,7 +2221,7 @@ def limit_sell_order_usdt_open():
         'side': 'sell',
         'symbol': 'mocked',
         'datetime': arrow.utcnow().isoformat(),
-        'timestamp': arrow.utcnow().int_timestamp,
+        'timestamp': arrow.utcnow().int_timestamp * 1000,
         'price': 2.20,
         'amount': 30.0,
         'filled': 0.0,
@@ -2238,6 +2246,7 @@ def market_buy_order_usdt():
         'type': 'market',
         'side': 'buy',
         'symbol': 'mocked',
+        'timestamp': arrow.utcnow().int_timestamp * 1000,
         'datetime': arrow.utcnow().isoformat(),
         'price': 2.00,
         'amount': 30.0,
@@ -2294,6 +2303,7 @@ def market_sell_order_usdt():
         'type': 'market',
         'side': 'sell',
         'symbol': 'mocked',
+        'timestamp': arrow.utcnow().int_timestamp * 1000,
         'datetime': arrow.utcnow().isoformat(),
         'price': 2.20,
         'amount': 30.0,
