@@ -902,6 +902,8 @@ def test_api_status(botclient, mocker, ticker, fee, markets):
         'buy_tag': None,
         'timeframe': 5,
         'exchange': 'binance',
+        'orders': [ANY],
+
     }
 
     mocker.patch('freqtrade.exchange.Exchange.get_rate',
@@ -1089,6 +1091,7 @@ def test_api_forcebuy(botclient, mocker, fee):
         'buy_tag': None,
         'timeframe': 5,
         'exchange': 'binance',
+        'orders': [],
     }
 
 
