@@ -901,8 +901,7 @@ def test_to_json(default_conf, fee):
                       'buy_tag': None,
                       'timeframe': None,
                       'exchange': 'binance',
-                      'filled_entry_orders': [],
-                      'filled_exit_orders': []
+                      'orders': [],
                       }
 
     # Simulate dry_run entries
@@ -970,8 +969,7 @@ def test_to_json(default_conf, fee):
                       'buy_tag': 'buys_signal_001',
                       'timeframe': None,
                       'exchange': 'binance',
-                      'filled_entry_orders': [],
-                      'filled_exit_orders': []
+                      'orders': [],
                       }
 
 
